SATLAS2 – Statistical Analysis Toolbox for Laser Spectroscopy, version 2 — satlas2 0.1.5 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# SATLAS2 – Statistical Analysis Toolbox for Laser Spectroscopy, version 2

# Purpose

This Python package has been created with the goal of creating an easier interface for the analysis of data gathered from laser spectroscopy experiments. Support for fitting the spectra, using both \(\chi^2\)-fitting and Maximum Likelihood Estimation routines, are present.

# Dependencies

This package has the following dependencies:

> - NumPy

> - Matplotlib

> - SciPy

> - h5py

> - emcee

> - sympy

> - LMFIT

> - numdifftools

> - uncertainties

> - tqdm

> - pandas

# Contents

- Architecture of SATLAS2
- Tutorial
- API reference

# Indices and tables

- Index

- Module Index

- Search Page